@@ -633,6 +633,50 @@ class Instances(JavaObject):
 
         return result
 
+    def to_numpy(self, internal=False):
+        """
+        Turns the dataset into a numpy matrix.
+
+        :param internal: whether to return the internal format
+        :type internal: bool
+        :return: the dataset as matrix
+        :rtype: np.ndarray
+        """
+        names = []
+        for n in range(self.num_attributes):
+            names.append(self.attribute(n).name)
+
+        if internal:
+            result = np.empty((self.num_instances, self.num_attributes))
+            for i in range(self.num_instances):
+                values = self.get_instance(i).values
+                for n in range(len(values)):
+                    result[i, n] = values[n]
+            return result
+        else:
+            numeric = []
+            formats = []
+            for n in range(self.num_attributes):
+                if self.attribute(n).is_numeric:
+                    numeric.append(True)
+                    formats.append("float64")
+                else:
+                    numeric.append(False)
+                    formats.append("object")
+            result = np.empty((self.num_instances, ), dtype=",".join(formats))
+            data = []
+            for i in range(self.num_instances):
+                inst = self.get_instance(i)
+                row = []
+                for n in range(self.num_attributes):
+                    if numeric[n]:
+                        row.append(inst.get_value(n))
+                    else:
+                        row.append(inst.get_string_value(n))
+                data.append(tuple(row))
+            result[:] = data
+            return result
+
 
 class Instance(JavaObject):
     """
@@ -922,6 +966,45 @@ class Instance(JavaObject):
         """
         return missing_value()
 
+    def to_numpy(self, internal=False):
+        """
+        Turns the instance into a numpy matrix.
+
+        :param internal: whether to return the internal format
+        :type internal: bool
+        :return: the dataset as matrix with single row
+        :rtype: np.ndarray
+        """
+        names = []
+        for n in range(self.num_attributes):
+            names.append(self.dataset.attribute(n).name)
+
+        if internal:
+            result = np.empty((1, self.num_attributes))
+            values = self.values
+            for n in range(len(values)):
+                result[0, n] = values[n]
+            return result
+        else:
+            numeric = []
+            formats = []
+            for n in range(self.dataset.num_attributes):
+                if self.dataset.attribute(n).is_numeric:
+                    numeric.append(True)
+                    formats.append("float64")
+                else:
+                    numeric.append(False)
+                    formats.append("object")
+            result = np.empty((1, ), dtype=",".join(formats))
+            row = []
+            for n in range(self.num_attributes):
+                if numeric[n]:
+                    row.append(self.get_value(n))
+                else:
+                    row.append(self.get_string_value(n))
+            result[0] = tuple(row)
+            return result
+
 
 class Attribute(JavaObject):
     """
